==> dde-device-formatter_1.5.4.tar.xz: BUILD/translations/dde-device-formatter_pt.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.1">
<context>
    <name>FinishPage</name>
    <message>
        <location filename="../view/finishpage.cpp" line="42"/>
        <source>Format successful</source>
        <translation>Formatação concluída</translation>
    </message>
</context>
<context>
    <name>FormatingPage</name>
    <message>
        <location filename="../view/formatingpage.cpp" line="47"/>
        <source>Formatting the disk, please wait...</source>
        <translation>A formatar o disco, por favor aguarde...</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../view/mainpage.cpp" line="119"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="137"/>
        <source>Label</source>
        <translation>Etiqueta do volume</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="146"/>
        <source>Quick Format</source>
        <translation>Formatação Rápida</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="163"/>
        <source>Formatting will erase all data on the disk.</source>
        <translation>A formatação apagará todos os dados no disco.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../view/mainwindow.cpp" line="88"/>
        <location filename="../view/mainwindow.cpp" line="106"/>
        <source>Format</source>
        <translation>Formatar</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="162"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="167"/>
        <source>Formatting...</source>
        <translation>A formatar...</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="193"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="199"/>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="200"/>
        <source>Your disk has been removed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your disk is removed when formatting</source>
        <translation type="vanished">O seu disco é removido ao formatar</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="203"/>
        <source>Failed to format the device</source>
        <translation>Erro ao formatar o dispositivo</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="204"/>
        <source>Reformat</source>
        <translation>Reformatar</translation>
    </message>
</context>
<context>
    <name>MessageDialog</name>
    <message>
        <location filename="../dialogs/messagedialog.cpp" line="43"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../utils/udisksutils.cpp" line="55"/>
        <source>System Disk</source>
        <translation>Disco do sistema</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="59"/>
        <source>%1 Encrypted</source>
        <translation>%1 Encriptado</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="61"/>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="90"/>
        <source>Device does not exist</source>
        <translation>O dispositivo não existe</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>The device is read-only</source>
        <translation>O dispositivo é apenas de leitura</translation>
    </message>
    <message>
        <source>Cannot format local device</source>
        <translation type="vanished">Não é possível formatar o dispositivo local</translation>
    </message>
</context>
<context>
    <name>WarnPage</name>
    <message>
        <location filename="../view/warnpage.cpp" line="43"/>
        <source>Formatting will erase all data on this disk, are you sure you want to continue? It cannot be restored.</source>
        <translation>A formatação apagará todos os dados neste disco, tem a certeza que deseja continuar? Isto não poderá ser restaurado.</translation>
    </message>
</context>
</TS>

==> dde-device-formatter_1.5.5.tar.xz: BUILD/translations/dde-device-formatter_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>FinishPage</name>
    <message>
        <location filename="../view/finishpage.cpp" line="22"/>
        <source>Format successful</source>
        <translation>Formatação concluída</translation>
    </message>
</context>
<context>
    <name>FormatingPage</name>
    <message>
        <location filename="../view/formatingpage.cpp" line="29"/>
        <source>Formatting the disk, please wait...</source>
        <translation>A formatar o disco, por favor aguarde...</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <location filename="../view/mainpage.cpp" line="99"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="117"/>
        <source>Label</source>
        <translation>Etiqueta do volume</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="127"/>
        <source>Quick Format</source>
        <translation>Formatação Rápida</translation>
    </message>
    <message>
        <location filename="../view/mainpage.cpp" line="144"/>
        <source>Formatting will erase all data on the disk.</source>
        <translation>A formatação apagará todos os dados no disco.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../view/mainwindow.cpp" line="68"/>
        <source>Format</source>
        <translation>Formatar</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="250"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="256"/>
        <source>Formatting...</source>
        <translation>A formatar...</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="290"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="303"/>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="304"/>
        <source>Your disk has been removed</source>
        <translation>O seu disco foi removido</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="308"/>
        <source>Failed to format the device</source>
        <translation>Erro ao formatar o dispositivo</translation>
    </message>
    <message>
        <location filename="../view/mainwindow.cpp" line="309"/>
        <source>Reformat</source>
        <translation>Reformatar</translation>
    </message>
</context>
<context>
    <name>MessageDialog</name>
    <message>
        <location filename="../dialogs/messagedialog.cpp" line="23"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../utils/udisksutils.cpp" line="40"/>
        <source>System Disk</source>
        <translation>Disco do sistema</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="46"/>
        <source>%1 Encrypted</source>
        <translation>%1 Encriptado</translation>
    </message>
    <message>
        <location filename="../utils/udisksutils.cpp" line="50"/>
        <source>%1 Volume</source>
        <translation>%1 Volume</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>dde device formatter</source>
        <translation>Formatador de dispositivo DDE</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="97"/>
        <source>Device does not exist</source>
        <translation>O dispositivo não existe</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="107"/>
        <source>The device is read-only</source>
        <translation>O dispositivo é apenas de leitura</translation>
    </message>
</context>
<context>
    <name>WarnPage</name>
    <message>
        <location filename="../view/warnpage.cpp" line="23"/>
        <source>Formatting will erase all data on this disk, are you sure you want to continue? It cannot be restored.</source>
        <translation>A formatação apagará todos os dados neste disco, tem a certeza que deseja continuar? Isto não poderá ser restaurado.</translation>
    </message>
</context>
</TS>
